/// <reference types="node" />
import express from "express";
import type { Handler, Document } from "openapi-backend";
import type { SimulationStore, ExtendSimulationActionsInput, ExtendSimuationActions } from "./store";
import type { ExtendSimulationSchemaInput, ExtendSimulationSchema } from "./store/schema";
import type { RecursivePartial } from "./store/types";
import type { Context as OpenAPIBackendContext } from "openapi-backend";
import type { Request as ExpressRequest, Response as ExpressResponse } from "express";
type SimulationHandlerFunctions = (context: OpenAPIBackendContext, request: ExpressRequest, response: ExpressResponse) => void;
export type SimulationHandlers = Record<string, SimulationHandlerFunctions>;
export type { ExtendSimuationActions, ExtendSimulationSchema, SimulationStore };
export type { AnyState } from "starfx";
export declare function createFoundationSimulationServer<ExtendedSimulationSchema, ExtendedSimulationActions>({ port, openapi, extendStore, extendRouter, }: {
    port: number;
    openapi?: {
        document: Document | RecursivePartial<Document>[];
        handlers: (simulationStore: SimulationStore<ExtendedSimulationSchema, ExtendedSimulationActions>) => Record<string, Handler | Record<string, Handler>>;
        apiRoot?: string;
    };
    extendStore?: {
        schema: ExtendSimulationSchemaInput<ExtendedSimulationSchema>;
        actions: ExtendSimulationActionsInput<ExtendedSimulationActions, ExtendedSimulationSchema>;
    };
    extendRouter?(router: express.Router, simulationStore: SimulationStore<ExtendedSimulationSchema, ExtendedSimulationActions>): void;
}): Promise<{
    listen: (portOverride?: number) => Promise<import("http").Server>;
}>;
export declare function startFoundationSimulationServer<ExtendedSimulationSchema, ExtendedSimulationActions>(arg: Parameters<typeof createFoundationSimulationServer<ExtendedSimulationSchema, ExtendedSimulationActions>>[0]): Promise<import("http").Server>;
//# sourceMappingURL=index.d.ts.map